#! /usr/bin/rscript

library(reshape)
library(ggplot2)
library(robust)

## timings <- data.frame(stock=scan('data-10.6.1-4200rpm-USB/Stock.csv'),
##                       static=scan('data-10.6.1-4200rpm-USB/Static.csv'),
##                       libxul=scan('data-10.6.1-4200rpm-USB/LIBXUL.csv'))

## timings <- data.frame(stock=scan('data-10.6.1-7200rpm/Stock.csv'),
##                       static=scan('data-10.6.1-7200rpm/Static.csv'),
##                       libxul=scan('data-10.6.1-7200rpm/LIBXUL.csv'))

## timings <- data.frame(stock=scan('data-10.6.2-5400rpm/Stock.csv'),
##                       static=scan('data-10.6.2-5400rpm/Static.csv'),
##                       libxul=scan('data-10.6.2-5400rpm/LIBXUL.csv'))

timings <- data.frame(stock=scan('data-10.6.2-ssd/Stock.csv'),
                      static=scan('data-10.6.2-ssd/Static.csv'),
                      libxul=scan('data-10.6.2-ssd/LIBXUL.csv'))

# There are 101 observations in each column of 'timings'.  The first
# of these is the numeric maximum for all but 'current.static' and is well
# beyond the 90% quantile for most of them, as you can see here.

print(cast(melt(timings, id.vars=c()), variable ~ .,
           fun.aggregate = function(x) c(x[1], x[1] - quantile(x, 0.9))))

# Thus, we discard the first observation in all columns.
timings.c <- timings[2:dim(timings)[1],]

# Reorganize the data the way lmRob and ggplot like it.
timings.f <- rename(melt(timings.c, id.vars=c(), variable_name='condition'),
                    c(value='time'))

# Take the model
model <- lmRob(time ~ condition, data=timings.f)

options(digits=3)
print(anova(model))
print(summary(model))

# Normal q-q plot of residuals
pdf(file='qq-residuals.pdf', width=8, height=8)
print(plot(model, 2))
dev.off()

# Predictions with data
timings.p <- timings.f[]
timings.p$predict <- predict(model)
pdf(file='prediction-with-data.pdf', width=6.41, height=11.4)
p <- ggplot(data=timings.p, aes(x=condition, colour=condition)) +
  geom_point(aes(y=time), position=position_jitter(w=0.1, h=0), alpha=0.7) +
  geom_line(aes(y=predict, group=condition))
print(p)
dev.off()

# Specific questions to be answered by pairwise comparisons.

print(with(timings.c, wilcox.test(stock, static)))
print(with(timings.c, wilcox.test(stock, libxul)))
print(with(timings.c, wilcox.test(static, libxul)))

# cast(melt(timings, id.vars=c()), variable ~ ., fun.aggregate=median)
